.. django-daraja documentation master file, created by
   sphinx-quickstart on Wed Oct 31 17:02:06 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-daraja's documentation!
=========================================

This is a django library that interacts with the MPESA Daraja API.

.. toctree::
   :maxdepth: 2
   
   01-testing



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
